@@ -2,4 +2,4 @@
 
 from .camel_cased_ordering import CamelCasedOrderingMixin
 from .nulls_always_last_ordering import NullsAlwaysLastOrderingMixin
-from .vaildate_filter_set import ValidateFilterSetMixin
+from .validate_filter_set import ValidateFilterSetMixin
